LayoutMixin mixin base

Superclass constraints
Available extensions

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$align({Alignment alignment = Alignment.center, double? widthFactor, double? heightFactor}) Widget

Available on Widget, provided by the StyleExtension extension

$borderAll({Color color = const Color(0xFF000000), double width = 1.0, BorderStyle style = BorderStyle.solid, double strokeAlign = BorderSide.strokeAlignInside, double radius = 0}) Widget

Available on Widget, provided by the StyleExtension extension

$center({double? widthFactor, double? heightFactor}) Widget

Available on Widget, provided by the StyleExtension extension

$debugBorder({double paddingAll = 6}) Widget

Available on Widget, provided by the StyleExtension extension

$expanded({int flex = 1}) Widget

Available on Widget, provided by the StyleExtension extension

$flexible({int flex = 1, FlexFit fit = FlexFit.loose}) Widget

Available on Widget, provided by the StyleExtension extension

$padding(EdgeInsetsGeometry padding) Widget

Available on Widget, provided by the StyleExtension extension

$paddingAll(double value) Widget

Available on Widget, provided by the StyleExtension extension

$paddingOnly({double left = 0.0, double top = 0.0, double right = 0.0, double bottom = 0.0}) Widget

Available on Widget, provided by the StyleExtension extension

$paddingSymmetric({double vertical = 0.0, double horizontal = 0.0}) Widget

Available on Widget, provided by the StyleExtension extension

createElement() Element
Inflates this configuration to a concrete instance.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
flutterPage(BuildContext context, ToUri uri) Page
flutter default impl TODO flutterPage是否也变为builder形式?
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited